# Celmech

Celmech is a collection of analytical and semianalytical tools for celestial mechanics, developed by Sam Hadden, Dan Tamayo, and David Hernandez.

Documentation can be found at https://celmech.readthedocs.io/en/latest/.

[![GPL](https://img.shields.io/badge/license-GPL-green.svg?style=flat)](https://github.com/shadden/celmech/blob/master/LICENSE)
[![Binder](http://mybinder.org/badge.svg)](https://beta.mybinder.org/v2/gh/shadden/celmech/master)
[![DOI](https://zenodo.org/badge/85832048.svg)](https://zenodo.org/badge/latestdoi/85832048)
[![Paper](https://img.shields.io/badge/arXiv-2205.10385-green.svg?style=flat)](https://arxiv.org/abs/2205.10385)
